<template>
  <div class="mobile-container">

    <van-form @submit="onSubmit">
      <van-field
        v-model="params.applicationCase"
        rows="2"
        autosize
        label="申请事由"
        type="textarea"
        maxlength="200"
        placeholder="申请事由"
        show-word-limit
        :rules="[{ required: true, message: '请填写采购申请事由' }]"
      />

      <van-field
        v-model="params.applicationDate"
        label="申请日期"
        disabled
        :rules="[{ required: true, message: '请填写申请日期' }]"
      />
      <van-field
        v-model="params.applicant"
        label="申请人"
        disabled
      />
      <van-field
        v-model="params.applicationDeptName"
        label="申请部门"
        disabled
      />

      <div v-for="item,idx in purchasingDetailList" :key="item.id">
        <div class="group-title">申请物资明细 <span v-if="idx!==0"> {{ idx }}  <van-icon name="close" @click="deleteDetail(idx)" /> </span> </div>
        <van-field
          v-model="item.name"
          label="品名"
          :maxlength="30"
          :rules="[{ required: true, message: '请填写物资品名' }]"
        />
        <van-field
          v-model="item.model"
          :maxlength="50"
          label="规格型号"
        />
        <van-field
          v-model="item.quantity"
          type="number"
          :maxlength="10"
          label="申请数量"
        />
      </div>
      <div class="group-bottom" @click="addRow">添加明细</div>
      <div style="margin: 16px;">
        <van-button block type="info" :loading="loading" native-type="submit">提交</van-button>
      </div>
    </van-form>
  </div>
</template>

<script>

import purchasingManage from '@/api/manager/material/purchasingManage.js'
import { Toast } from 'vant'

export default {
  name: 'MobileMaterialPurchasing',
  components: {

  },
  data() {
    return {
      purchasingDetailList: [],
      params: { },
      loading: false,

      title: '设备详情',
      deviceData: {},
      paramsValueList: [],
      extendParams: []

    }
  },
  mounted() {
    this.device = this.$route.query.id
    this.add()
  },
  methods: {
    add() {
      var date = new Date()
      this.params = {
        applicant: '',
        applicationCase: '',
        applicationDate: date.format('yyyy-MM-dd'),
        approver: '',
        approvedDate: '',
        id: null,
        memo: '',
        pkVal: '',
        detailList: [],
        sn: 0,
        version: 0
      }
      this.purchasingDetailList = []
      this.addRow()
      const userinfo = this.$store.state.user.currentUserDetail
      if (userinfo !== null) {
        this.params.applicationDept = userinfo.org[0].orgId
        this.params.applicationDeptName = userinfo.org[0].orgName
        this.params.applicant = userinfo.user.fullname
      } else {
        Toast.fail('登录信息异常，请联系管理员！')
      }
    },

    addRow() { //
      var row = {
        quantity: 0,
        name: '',
        model: '',
        memo: '',
        id: null,
        purchasingId: null,
        materialInfoId: null
      }
      this.purchasingDetailList.push(row)
    },
    deleteDetail(index) {
      this.purchasingDetailList.splice(index, 1)
    },

    onSubmit() {
      let method
      if (!this.params.id) {
        // 新增
        method = purchasingManage.addPurchasing
      }
      if (this.params.id) {
        // 修改
        method = purchasingManage.editPurchasing
      }
      this.params.detailList = this.purchasingDetailList
      this.loading = true
      method(this.params, res => {
        this.loading = false
        if (res.state) {
          Toast.success('提交申请成功')
          this.add()
        } else {
          this.$message.warning(res.message)
        }
      })
    }

  }
}
</script>

<style lang="scss" scoped>
@import "@/assets/css/element-variables.scss";

::v-deep .van-field__label span {
    font-size: 14PX;
}

.mobile-container {
    width: 100%;
    min-height: 100%;
    font-size: 100px;
    background-color: $--mobile-bg;
}
::v-deep span{
    font-size: px;
}

.group-title{
    padding:20PX 16PX 10PX 16PX;
    color:#888888;
    font-size: 78px;
}
.group-bottom{
    padding:20PX 16PX 10PX 16PX;
    color:#3a6bf1;
    font-size: 48px;
}

.device-group{
    padding:16PX;
    margin-top: 16PX !important;
}
.group-title{
    padding:20PX 16PX 10PX 16PX;
    color:#888888;
    font-size: 78px;
}
.title-bar{
    display: inline-block;
    width: 4PX;
    height: 12PX;
    background-color: #1989fa;
    margin-right: 4PX;
    vertical-align: middle;
}
.device-cell{
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 6PX 0;

}
.device-name{
    font-size: 88px;
    color: $--mobile-text-main;
}
.cell-title{
    color:$--mobile-text-sub;
    font-size: 82px;
    margin-right: 10px;
}
.cell-value{
    color:$--mobile-text-main;
    font-size: 82px;
}
.margin-bottom{
    margin-bottom: 16PX!important;
}
.device-status .van-tag{
    padding: 4PX 6PX;
    font-size: 72px;
}
.van-cell-group--inset{
    margin: 0 0;
    border-radius:0;
}
.van-cell{
    justify-content: start
}

.van-cell__title,.van-cell__value{
    width: auto;
    flex: initial;
}
.van-cell__title{
    white-space:nowrap
}
.van-cell__value{
    padding-left: 10PX;
    text-align: left;
}
.van-cell__title span, .van-cell__value span{
    font-size: 76px;
    color:$--mobile-text-main;
}
.van-cell__title span{
    color:$--mobile-text-sub;
}
</style>
<style lang="scss">
@import "@/assets/css/vant-custom.scss";
</style>
